==> CalculiX-1.1.tbz: share/doc/CalculiX/cgx/images.pl <==
# LaTeX2HTML 99.1 release (March 30, 1999)
# Associate images original text with physical files.


$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=qu8.eps,width=10cm}{}put(100,33epsfig{file=te4.eps,width=10cm}{}put(100,0){4nodetetelement(type3)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="367" HEIGHT="318" ALIGN="BOTTOM" BORDER="0"
 SRC="img6.gif"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig {file=qu8.eps,width=10cm}}
...
...le=te4.eps,width=10cm}}
\put(100,0){
4 node tet element (type 3) }
\end{picture}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=tr6.eps,width=10cm}{}put(100,33{file=qu4.eps,width=10cm}{}put(100,0){4nodeshellelement(qu4,type9)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="366" HEIGHT="318" ALIGN="BOTTOM" BORDER="0"
 SRC="img5.gif"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig {file=tr6.eps,width=10cm}}
...
...eps,width=10cm}}
\put(100,0){
4 node shell element (qu4, type 9) }
\end{picture}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=be3.eps,width=9cm}{}put(100,330{file=tr3.eps,width=10cm}{}put(100,0){3nodeshellelement(tr3,type7)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="366" HEIGHT="318" ALIGN="BOTTOM" BORDER="0"
 SRC="img4.gif"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig {file=be3.eps,width=9cm}}
\...
...eps,width=10cm}}
\put(100,0){
3 node shell element (tr3, type 7) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=disc.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="409" HEIGHT="335" BORDER="0"
 SRC="img16.gif"
 ALT="\begin{figure}
\epsfig {file=disc.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,90)(0,150)%put(0,0){{epsfig{file=be2.eps,width=9cm}{}put(100,0){2nodebeamelement(be2,type11)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="77" HEIGHT="56" ALIGN="BOTTOM" BORDER="0"
 SRC="img3.gif"
 ALT="\begin{picture}(90,90)(0,150)
%
\put(0,0){\epsfig {file=be2.eps,width=9cm}}
\put(100,0){
2 node beam element (be2, type 11) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=sphere.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="403" HEIGHT="420" BORDER="0"
 SRC="img18.gif"
 ALT="\begin{figure}
\epsfig {file=sphere.eps,width=12cm}\end{figure}">|; 

$key = q/{figure}{epsfig{file=naca23012.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="429" HEIGHT="393" BORDER="0"
 SRC="img20.gif"
 ALT="\begin{figure}
\epsfig{file=naca23012.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,310){{epsfig{file=te10.eps,width=10cm}{}put(100,2{file=he8.eps,width=10cm}{}put(100,0){8nodebrickelement(he8,type1)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="366" HEIGHT="305" ALIGN="BOTTOM" BORDER="0"
 SRC="img7.gif"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,310){\epsfig {file=te10.eps,width=10cm}}...
...eps,width=10cm}}
\put(100,0){
8 node brick element (he8, type 1) }
\end{picture}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=pe15.eps,width=6cm}{}put(100,330){15nodepentaelement(pe15,type5)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="366" HEIGHT="309" ALIGN="BOTTOM" BORDER="0"
 SRC="img9.gif"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig {file=pe15.eps,width=6cm}}
\put(100,330){
15 node penta element (pe15, type 5) }
\end{picture}">|; 

$key = q/{displaymath}sigma_{(xx+yy)}=sigma_{xx}+sigma_{yy}{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="144" HEIGHT="30" BORDER="0"
 SRC="img11.gif"
 ALT="\begin{displaymath}\sigma_{(xx+yy)} = \sigma_{xx} + \sigma_{yy} \end{displaymath}">|; 

$key = q/{displaymath}left[array{{ccc}sigma_{xx}-lambda&sigma_{xy}&sigma_{xz}sigma_{yx}&sray{{c}nxnynzarray{right]=left[array{{c}000array{right]{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="342" HEIGHT="64" BORDER="0"
 SRC="img15.gif"
 ALT="\begin{displaymath}
\left [
\begin{array}{ccc}
\sigma_{xx}-\lambda &amp; \sigma_{xy}...
... ]
=
\left [
\begin{array}{c}
0\\\\
0\\\\
0
\end{array}\right ]
\end{displaymath}">|; 

$key = q/sigma;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="13" ALIGN="BOTTOM" BORDER="0"
 SRC="img12.gif"
 ALT="$\sigma$">|; 

$key = q/{displaymath}sigma_{vM}=frac{1}{sqrt{2}}sqrt{(sigma_{x}-sigma_{y})^{2}+(sigma_{ygma_{x})^{2}+6tau_{yz}^{2}+6tau_{zx}^{2}+6tau_{xy}^{2}}{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="496" HEIGHT="42" BORDER="0"
 SRC="img10.gif"
 ALT="\begin{displaymath}\sigma_{vM} = \frac{1}{\sqrt{2}} \sqrt{(\sigma_{x}-\sigma_{y}...
...-\sigma_{x})^{2}+6\tau_{yz}^{2}+6\tau_{zx}^{2}+6\tau_{xy}^{2}} \end{displaymath}">|; 

$key = q/{figure}{epsfig{file=sphere_vol.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="348" HEIGHT="426" BORDER="0"
 SRC="img19.gif"
 ALT="\begin{figure}
\epsfig {file=sphere_vol.eps,width=12cm}\end{figure}">|; 

$key = q/{displaymath}sigma^3-(sigma_{xx}+sigma_{yy}+sigma_{zz})sigma^2+(sigma_{xx}sigma_}sigma_{zz}+sigma_{zz}sigma_{xx}-tau_{xy}^2-tau_{yz}^2-{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="474" HEIGHT="30" BORDER="0"
 SRC="img13.gif"
 ALT="\begin{displaymath}\sigma^3 - (\sigma_{xx}+\sigma_{yy}+\sigma_{zz})\sigma^2 + (\...
...{yy}\sigma_{zz}+\sigma_{zz}\sigma_{xx}-\tau_{xy}^2-\tau_{yz}^2-\end{displaymath}">|; 

$key = q/{displaymath}tau_{zx}^2)sigma-(sigma_{xx}sigma_{yy}sigma_{zz}+2tau_{xy}tau_{yz}ttau_{yz}^2-sigma_{yy}tau_{zx}^2-sigma_{zz}tau_{xy}^2)=0{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="453" HEIGHT="30" BORDER="0"
 SRC="img14.gif"
 ALT="\begin{displaymath}\tau_{zx}^2)\sigma - (\sigma_{xx}\sigma_{yy}\sigma_{zz}+2\tau...
...\tau_{yz}^2-\sigma_{yy}\tau_{zx}^2-\sigma_{zz}\tau_{xy}^2) = 0 \end{displaymath}">|; 

$key = q/{figure}{epsfig{file=cylinder.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="409" HEIGHT="465" BORDER="0"
 SRC="img17.gif"
 ALT="\begin{figure}
\epsfig {file=cylinder.eps,width=12cm}\end{figure}">|; 

$key = q/{figure}{epsfig{file=mainmenu.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="543" HEIGHT="479" BORDER="0"
 SRC="img2.gif"
 ALT="\begin{figure}
\epsfig {file=mainmenu.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=he20.eps,width=10cm}{}put(100,3g{file=pe6.eps,width=6cm}{}put(100,0){6nodepentaelement(pe6,type2)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="366" HEIGHT="318" ALIGN="BOTTOM" BORDER="0"
 SRC="img8.gif"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig {file=he20.eps,width=10cm}}...
....eps,width=6cm}}
\put(100,0){
6 node penta element (pe6, type 2) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=mainwindow.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="515" HEIGHT="376" BORDER="0"
 SRC="img1.gif"
 ALT="\begin{figure}
\epsfig {file=mainwindow.eps,width=12cm}\end{figure}">|; 

1;

==> CalculiX-1.3.tbz: share/doc/CalculiX/cgx/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=tr6.eps,width=10cm}{}put(100,33{file=qu4.eps,width=10cm}{}put(100,0){4nodeshellelement(qu4,type9)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="450" HEIGHT="908" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig{file=tr6.eps,width=10cm} }
...
...ps,width=10cm} }
\put(100,0){
4 node shell element (qu4, type 9) }
\end{picture}">|; 

$key = q/sigma;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="13" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$\sigma$">|; 

$key = q/{picture}(90,180)(0,330)%put(0,310){{epsfig{file=te10.eps,width=10cm}{}put(100,2{file=he8.eps,width=10cm}{}put(100,0){8nodebrickelement(he8,type1)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="452" HEIGHT="922" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,310){\epsfig{file=te10.eps,width=10cm} }...
...ps,width=10cm} }
\put(100,0){
8 node brick element (he8, type 1) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=halter.eps,width=9cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="407" HEIGHT="354" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="\begin{figure}\epsfig{file=halter.eps,width=9cm}\end{figure}">|; 

$key = q/{figure}{epsfig{file=sphere.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="544" HEIGHT="473" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="\begin{figure}\epsfig{file=sphere.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=pe15.eps,width=6cm}{}put(100,330){15nodepentaelement(pe15,type5)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="422" HEIGHT="348" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig{file=pe15.eps,width=6cm} }
\put(100,330){
15 node penta element (pe15, type 5) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=disc.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="544" HEIGHT="473" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="\begin{figure}\epsfig{file=disc.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=be3.eps,width=9cm}{}put(100,330=tr3.eps,width=10cm}{}put(100,0){3nodeshellelement(tr3,tr3u,type7)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="450" HEIGHT="874" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig{file=be3.eps,width=9cm} }
\...
...th=10cm} }
\put(100,0){
3 node shell element (tr3, tr3u, type 7) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=mesh2d.eps,width=10cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="452" HEIGHT="586" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\begin{figure}\epsfig{file=mesh2d.eps,width=10cm}\end{figure}">|; 

$key = q/{figure}{epsfig{file=naca23012.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="544" HEIGHT="473" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\begin{figure}\epsfig{file=naca23012.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=he20.eps,width=10cm}{}put(100,3g{file=pe6.eps,width=6cm}{}put(100,0){6nodepentaelement(pe6,type2)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="450" HEIGHT="895" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig{file=he20.eps,width=10cm} }...
...eps,width=6cm} }
\put(100,0){
6 node penta element (pe6, type 2) }
\end{picture}">|; 

$key = q/{figure}{epsfig{file=mainmenu.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="544" HEIGHT="479" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\begin{figure}\epsfig{file=mainmenu.eps,width=12cm}\end{figure}">|; 

$key = q/{picture}(90,180)(0,330)%put(0,360){{epsfig{file=qu8.eps,width=10cm}{}put(100,33epsfig{file=te4.eps,width=10cm}{}put(100,0){4nodetetelement(type3)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="450" HEIGHT="894" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\begin{picture}(90,180)(0,330)
%
\put(0,360){\epsfig{file=qu8.eps,width=10cm} }
...
...e=te4.eps,width=10cm} }
\put(100,0){
4 node tet element (type 3) }
\end{picture}">|; 

$key = q/{picture}(90,90)(0,150)%put(0,0){{epsfig{file=be2.eps,width=9cm}{}put(100,0){2nodebeamelement(be2,type11)}{picture};AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="412" HEIGHT="300" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\begin{picture}(90,90)(0,150)
%
\put(0,0){\epsfig{file=be2.eps,width=9cm} }
\put(100,0){
2 node beam element (be2, type 11) }
\end{picture}">|; 

$key = q/{displaymath}sigma_{vM}=frac{1}{sqrt{2}}sqrt{(sigma_{x}-sigma_{y})^{2}+(sigma_{ygma_{x})^{2}+6tau_{yz}^{2}+6tau_{zx}^{2}+6tau_{xy}^{2}}{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="494" HEIGHT="42" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\begin{displaymath}\sigma_{vM} = \frac{1}{\sqrt{2}} \sqrt{(\sigma_{x}-\sigma_{y}...
...-\sigma_{x})^{2}+6\tau_{yz}^{2}+6\tau_{zx}^{2}+6\tau_{xy}^{2}} \end{displaymath}">|; 

$key = q/{displaymath}tau_{zx}^2)sigma-(sigma_{xx}sigma_{yy}sigma_{zz}+2tau_{xy}tau_{yz}ttau_{yz}^2-sigma_{yy}tau_{zx}^2-sigma_{zz}tau_{xy}^2)=0{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="454" HEIGHT="30" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\begin{displaymath}\tau_{zx}^2)\sigma - (\sigma_{xx}\sigma_{yy}\sigma_{zz}+2\tau...
...\tau_{yz}^2-\sigma_{yy}\tau_{zx}^2-\sigma_{zz}\tau_{xy}^2) = 0 \end{displaymath}">|; 

$key = q/{figure}{epsfig{file=sphere_vol.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="544" HEIGHT="473" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="\begin{figure}\epsfig{file=sphere_vol.eps,width=12cm}\end{figure}">|; 

$key = q/{figure}{epsfig{file=cylinder.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="544" HEIGHT="473" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="\begin{figure}\epsfig{file=cylinder.eps,width=12cm}\end{figure}">|; 

$key = q/{displaymath}left[array{{ccc}sigma_{xx}-lambda&sigma_{xy}&sigma_{xz}sigma_{yx}&sray{{c}nxnynzarray{right]=left[array{{c}000array{right]{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="341" HEIGHT="64" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="\begin{displaymath}
\left [
\begin{array}{ccc}
\sigma_{xx}-\lambda &amp; \sigma_{xy}...
... ]
=
\left [
\begin{array}{c}
0\\\\
0\\\\
0
\end{array}\right ]
\end{displaymath}">|; 

$key = q/{displaymath}sigma_{(xx+yy)}=sigma_{xx}+sigma_{yy}{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="144" HEIGHT="30" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\begin{displaymath}\sigma_{(xx+yy)} = \sigma_{xx} + \sigma_{yy} \end{displaymath}">|; 

$key = q/{displaymath}sigma^3-(sigma_{xx}+sigma_{yy}+sigma_{zz})sigma^2+(sigma_{xx}sigma_}sigma_{zz}+sigma_{zz}sigma_{xx}-tau_{xy}^2-tau_{yz}^2-{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="473" HEIGHT="30" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\begin{displaymath}\sigma^3 - (\sigma_{xx}+\sigma_{yy}+\sigma_{zz})\sigma^2 + (\...
...{yy}\sigma_{zz}+\sigma_{zz}\sigma_{xx}-\tau_{xy}^2-\tau_{yz}^2-\end{displaymath}">|; 

$key = q/{figure}{epsfig{file=mainwindow.eps,width=12cm}{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="543" HEIGHT="417" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\begin{figure}\epsfig{file=mainwindow.eps,width=12cm}\end{figure}">|; 

1;
